@@ -16,7 +16,7 @@ If you read with API, you need to use spreadsheetId and credentials (it is the j
 you also need to add the account email associated to the credentials as user shared in the google sheet.
 
 """
-def read_gsheet(spreadsheetId, credentials = None, sheet = None):
+def read_gsheet(spreadsheetId, credentials = None, sheet = None, valueRenderOption = 'FORMATTED_VALUE'):
     
 
     if credentials is None:
@@ -56,7 +56,8 @@ def read_gsheet(spreadsheetId, credentials = None, sheet = None):
             range = '%s!%s'%(sheet, range)
         
         result_input = sheet_service.values().get(spreadsheetId = spreadsheetId,
-                                          range = range).execute()
+                                          range = range,
+                                          ValueRenderOption = ValueRenderOption).execute()
         
         values_input = result_input.get('values', [])
         
@@ -183,17 +184,7 @@ def __read_hubspot(settings: dict):
 ##################################
 
 
-def read_fb_ads(my_app_id, my_app_secret, my_access_token, start_date, end_date,
-                
-                
-                account_name = {'Numbers' : 'act_113103090066338',
-                                'Linkers' : 'act_203938767415072',
-                                'WinWay' : 'act_2591302164494270',
-                                'Miss Tariffa Agency' : 'act_280378753012689',
-                                'Humable' : 'act_284748836042514',
-                                'Miss Tariffa' : 'act_503932150489858',
-                                'We are Fiber' : 'act_638714426864395'
-                                }):
+def read_fb_ads(my_app_id, my_app_secret, my_access_token, start_date, end_date, account_name):
     
     from askdata.integrations import facebook_api
     
@@ -208,16 +199,7 @@ def read_fb_ads(my_app_id, my_app_secret, my_access_token, start_date, end_date,
 ################################
 
 
-def read_google_ads(start_date, end_date,
-                   
-                  admin_account = {'Be You': '291-824-5921'
-                                 ,'Humable': '760-045-3647'
-                                 ,'Linkers': '504-714-3560'
-                                 ,'Miss Tariffa Agency': '427-886-1215'
-                                 ,'Numbers': '794-577-9076'
-                                 ,'Wearefiber': '778-681-5313'
-                                  ,'ELLEGIEFFE SRL':'643-277-1546'
-                                },
+def read_google_ads(start_date, end_date, admin_account,
                    
                    yaml_file_path = 'googleads.yaml'):
     
